# IISK Configuration

## Initial Windows setup

At the first start-up of the IISK computer you need to add your personal information for the installed Windows 10 IoT Enterprise.

As described in [Prerequisites](prerequisites.md), the hostname needs to be resolvable by a local DNS. 
The computer name should be also a valid hostname. Not allowed are space or underscore characters. 
For further reference see here: [https://en.wikipedia.org/wiki/Hostname](https://en.wikipedia.org/wiki/Hostname)  

## Basic configuration of the dataFEED OPC suite

The IISK comes with a pre-installed and fully licensed dataFEED OPC Suite.  
The OPC UA server needs to be enabled and configured.

* Start the dataFEED OPC Suite Configurator from the icon in system tray.

![dataFEED OPC Suite Configurator Tray Icon](pictures/datafeed_start_configurator_icon.PNG)

* During the very first start enable all features in the dataFEED OPC Suite Configurator by just using the "OK" button to accept the default enabling of all features.  
* Navigate to "Data Destination" -> OPC UA Client and enable the checkbox "Activate OPC UA".  
* In the field "Server Endpoint" enter the domain name of your IISK computer into the field < Hostname >.  

![dataFEED OPC UA server config](pictures/datafeed_enable_OPCUAserver.PNG)  

* Edit the "Security Configuration" of the dataFEED OPC UA server and enable all security modes and security policies except the "None" mode/policy. 

![dataFEED OPC UA server security config](pictures/datafeed_OPCUA_security_configuration.PNG)  

For additional help of dataFEED source elements please refer to the dataFEED help/manual or the [Example](iisk_example.md)  

## Start and configure Docker for Windows

The applications iot-edge-opc-proxy and iot-edge-opc-publisher are docker images and run into docker containers.  
Docker for Windows is pre-installed.

* Start Docker for Windows via the symbolic link on the Desktop or from the Windows Start Menu and wait until the initial start up has finished.

![docker start](pictures/docker_start.PNG)  

* Open the context menu of the docker with right mouse click on the docker icon in the system tray and select the "Settings" menu entry.  

![docker settings tray icon](pictures/docker_settings_icon.PNG)  

* In the setting "Shared Drives" enable the share for drive "C".  
* Then use the "apply" button.

![docker share drive](pictures/docker_settings_shared_drive.PNG)

* When docker is running, then you could close the window.

**Note:**
If you want to know more about the useage of docker, please read: [https://docs.docker.com/reference/](https://docs.docker.com/reference/)

## Connect IISK with the Azure IoT hub

The IISK connect to the Azure IoT hub by the two applications iot-edge-opc-proxy and iot-edge-opc-publisher.  
These two applications should run into two separate docker containers.
Replace the scripts starting these applications in `C:\docker` with the new scripts provided with this documentation.

For further configuration you need to know the IPv4 address of the IISK computer, the domain name and the hostname.
To get this information you could open a command.com or powershell terminal and enter the commands `ipconfig` and `hostname`.

For starting the iot-edge-opc-proxy, you need to open the sample script [startProxy.bat](startProxy.bat) in an editor and modify it:

* Insert your IoT hub owner connection string into the variable `_HUB_CS`.
* In the setting of variable `MYDOMAINNAME=.example.com` replace the domain name part with the domain name of your IISK computer. If there is no domain name, define the variable as empty string: `MYDOMAINNAME=""`.
* In the setting of variable `MYIP="10.123.45.27"` replace the default IPv4 address with the IPv4 address of your IISK computer.
* (Optionally) replace the name `proxy-iisk` with an unique device id of your choice **Note: only lower case allowed**.

For starting the iot-edge-opc-publisher you also need to open the sample script [startPublisher.bat](startPublisher.bat) in an editor and modify it:

* Insert your IoT hub owner connection string into the variable `_HUB_CS`.
* Replace the domain name part of `publisher.example.com` with the domain name of your IISK computer.

Finally you need to execute the modified scripts by double click on the script icons or by calling them in a terminal window (command.com or powershell).
Starting the scripts for the first time, triggers a download for the defined images from [Docker Hub](https://hub.docker.com/).  
For further information about the scripts please refer to: [startProxy script](startProxy.md#the-startproxy-script) and [startPublisher script](startPublisher.md#the-startpublisher-script)

The `--restart always` option allows the two .bat scripts an automatic restart of the iot-edge-opc-proxy and iot-edge-opc-publisher containers. 
They always restart, unless the containers are explicitly stopped with the command `docker container stop'. 
For more details see here: [https://docs.docker.com/engine/reference/commandline/container_stop/](https://docs.docker.com/engine/reference/commandline/container_stop/)

---

Continue reading with:  
    * [Table of Content](README.md#table-of-content)  
    * [IISK Example](iisk_example.md#iisk-example)  

