# IISK Example

## Prerequisites

In order to follow this example configuration, you should have finished the [IISK configuration](iisk_configuration.md) in chapter three.

It is assumed that:

* The dataFEED OPC Suite has an [OPC UA server configured](iisk_configuration.md#basic-configuration-of-the-datafeed-opc-suite).

* The [docker](iisk_configuration.md#start-and-configure-docker-for-windows) is installed and running.

* The scripts for running [iot-edge-opc-proxy](startProxy.bat) and [iot-edge-opc-publisher](startPublisher.bat) have been edited and match to your local network and Azure configuration.

* Optional: The [Device Explorer Desktop App](https://github.com/Azure/azure-iot-sdk-csharp/blob/master/tools/DeviceExplorer/readme.md) can be used to view published data.
A pre-built version of Device Explorer Desktop App is available [here](https://github.com/Azure/azure-iot-sdk-csharp/releases/download/2018-3-13/SetupDeviceExplorer.msi).

The application [dataFEED Exporter](https://data-intelligence.softing.com/products/iot-gateways/datafeed-exporter/) is used to extract the address space of a Siemens TIA project. 
For further information please refer to the dataFEED OPC Suite manual.

## Running the iot-edge-opc-proxy and iot-edge-opc-publisher containers

The scripts are located in `C:\docker`

Run the [startProxy.bat](startProxy.bat) and [startPublisher.bat](startPublisher.bat)  
For further information about the scripts please refer to [startProxy.md](startProxy.md) and [startPublisher.md](startPublisher.md).  
When starting the scripts for the first time, the docker containers specified in the scripts are fetched from [Docker Hub](https://hub.docker.com/).  

![iot-edge-opc-proxy first run](pictures/proxy_fetch_container.PNG)  

![iot-edge-opc-publisher first run](pictures/publisher_fetch_container.PNG)  

The publisher script binds to a docker network which is mapped from the IISK host.  
Allow access to the _vpnkit.exe_ which is part of docker when the Windows firewall prompts for access permission.

![Allow Firewall vpnkit](pictures/firewall_vpnkit.PNG)  

After the download of the containers is finished the iot-edge-opc-proxy and iot-edge-opc-publisher containers will run.

![iot-edge-opc-proxy running](pictures/proxy_container_running.PNG)

![iot-edge-opc-publisher running](pictures/publisher_container_running.PNG)  

At this point the iot-edge-opc-proxy and iot-edge-opc-publisher have registered themselves at the Azure IoT hub. 

Now, the devices show up in the Azure IoT hub.

![Azure IoT Hub Devices](pictures/Azure-IoT-Hub-DeviceExplorer.png)  

Alternatively the registered devices can be viewed with the _Device Explorer Desktop App_.

![Device Explorer Devices View](pictures/Device-Explorer-Devicelist.PNG)  

## Connected factory - Access dataFEED OPC Suite 

### Configure an internal dataFEED source  

No further configuration is needed. Proceed with starting the dataFEED runtime [here](iisk_example.md#start-the-datafeed-runtime).  

### Configure an external dataFEED source: S7-1500 PLC

Open the data source settings and add a new Siemens S7 connection.

![dataFEED OPC Suite S7 add](pictures/dataFEED_Siemens_add_source.PNG)  

Enter a name for the connection and select the S7 protocol.  

![dataFEED OPC Suite S7 connection settings](pictures/dataFEED_Siemens_connection_settings.PNG)  

Enter the IP address of your PLC and click "Modify".  

![dataFEED OPC Suite S7 communication settings](pictures/dataFEED_Siemens_communication_settings.PNG)  

For the S7-1500 PLC family change the slot in the _RFC 1006 settings_ to 1.

![dataFEED OPC Suite S7 communication settings detail](pictures/dataFEED_Siemens_communication_settings_modify.PNG)  

In the _Extended Settigns_ click the "Connection Test" button.

![dataFEED OPC Suite S7 extended settings](pictures/dataFEED_Siemens_extended_settings.PNG)  

The connection test should complete successfully - if not, your configuration is false or the PLC is not available. For further information please refer to the dataFEED OPC Suite manual.

![dataFEED OPC Suite S7 connection test](pictures/dataFEED_Siemens_connection_test.PNG)  

Either create items in the address space or import items from a Siemens project.

1. Add items manualy  
    Click the "plus" button.

    ![dataFEED OPC Suite S7 add items manual](pictures/dataFEED_Siemens_address_space_manual_add.PNG)  
    
    Choose _Type: Tag_ and enter a name for the item and its syntax. 
    For this example choose mb0 for the syntax. 
    For further information about item syntax please refer to the dataFEED OPC Suite manual.  
    
    ![dataFEED OPC Suite S7 tag definition](pictures/dataFEED_Siemens_address_space_manual_add_tag_definition.PNG)
    
2. Import items from a SDFI file created by dataFEED Exporter  
    Click the "S7" button.

    ![dataFEED OPC Suite S7 symbol import](pictures/dataFEED_Siemens_address_space_symbol_import.PNG)
    
    Choose the symbol file that corresponds to your S7 PLC.  
    
    ![dataFEED OPC Suite S7 symbol import wizard](pictures/dataFEED_Siemens_address_space_symbol_import_wizard.PNG)  
    
    If the project contains multiple PLCs select one.  
    
    ![dataFEED OPC Suite S7 symbol import wizard](pictures/dataFEED_Siemens_address_space_symbol_import_wizard_2.PNG)  
    
    Select all items that you want to import.
    
    ![dataFEED OPC Suite S7 symbol import wizard](pictures/dataFEED_Siemens_address_space_symbol_import_wizard_3.PNG)  
    
    A results page is shown and after that the items are shown in the _Address Space Definition_.  
    
    ![dataFEED OPC Suite S7 address space](pictures/dataFEED_Siemens_address_space_symbol_import_finish.PNG)  

After the address space creation the configuration is finished. The connection overview shows the newly created connection.  

![dataFEED OPC Suite S7 connection overview](pictures/dataFEED_Siemens_add_source_finished.PNG)  

Proceed with [Start the dataFEED runtime](iisk_example.md#start-the-datafeed-runtime)  
For further information about configuration of dataFEED source elements and supported PLC types please refer to the dataFEED OPC Suite manual.  

### Start the dataFEED runtime

Select from the menu _Local Application_ **->** _Start_.

![dataFEED OPC Suite S7 connection overview](pictures/dataFEED_start_runtime.PNG)

If the configuration has changed, save the configuration when prompted.

![dataFEED OPC Suite S7 connection overview](pictures/dataFEED_start_runtime_save_prompt.PNG)  

### Browse the dataFEED OPC UA endpoint URI and select nodes for publishing

Open the Connected factory webpage and add the endpoint URI of the dataFEED OPC UA server. 

**Note:** The URL of your Connected factory is shown in [Azure Portal](https://portal.azure.com) if you click onto your Connected factory _App Service_.

![Connected Factory OPC Server Add](pictures/connected-factory-add-opcserver.png)  

*Connect* and then *Proceed* at the certificate warning.

![Connected Factory Certificate Warning](pictures/connected-factory-add-opcserver_cert_warning.PNG)  

An error message is shown on first connect, because the Connected factory certificate is untrusted in dataFEED OPC UA Server.  

![Connected Factory Connect Error](pictures/connected-factory-add-opcserver_conn_error.PNG)  

Select *Configure* in the certificates section of the dataFEED OPC UA settings.  

![dataFEED OPC UA configure certificates](pictures/datafeed_OPCUA_configure_certificates.PNG)  

Find the Connected factory UA client certificate in the rejected certificates store. 

![dataFEED OPC UA untrusted UA Web Client](pictures/datafeed_OPCUA_certificate_UA_Web_Client.PNG)  

Move the Connected factory UA client certificate to the trusted certificates store.  

![dataFEED OPC UA trusted UA Web Client](pictures/datafeed_OPCUA_certificate_UA_Web_Client_trusted.PNG)  

Connect again to the dataFEED OPC UA server. The connection succeeds and the root hierarchy of the OPC UA server is shown. 

![Connected Factory Browse Root](pictures/connected-factory-opc_server_browse_root.PNG)  

The OPC UA server hierarchy can be expanded and browsed by clicking on the nodes.

![Connected Factory Browse Hierarchy](pictures/connected-factory-opc_server_browse_hierarchy.PNG)

Right clicking an item brings up the context menu. Depending on access permissions *Read*, *Write* and *Publish* options are available.

![Connected Factory Item Context Menu](pictures/connected-factory-opc_server_context_menu.PNG)

Reading an item will show its current value.

![Connected Factory Item Read](pictures/connected-factory-opc_server_read.PNG)

To write an item, enter the new value and click *Write*.

![Connected Factory Item Write](pictures/connected-factory-opc_server_write_result.PNG)

An item can also be published via MQTT. 
This will instruct the iot-edge-opc-publisher component to create a subscription at the OPC UA server and monitor the item for value changes. 
On value change the dataset is send via MQTT to Azure IoT hub. A violett hook appears and shows that this value is published.  

![Connected Factory Item Publish](pictures/connected-factory-opc_server_publish.PNG)

Because the iot-edge-opc-publisher is untrusted in the dataFEED OPC UA server, the certificate will be also first in the rejected certificates store.  

![dataFEED OPC UA untrusted Publisher](pictures/datafeed_OPCUA_certificate_publisher.PNG)

Move the iot-edge-opc-publisher certificate to the trusted certificates store.

![dataFEED OPC UA trusted Publisher](pictures/datafeed_OPCUA_certificate_publisher_trusted.PNG)

From the publish success message a link to the *Time Series Insights* can be opened. This is a service from Microsoft Azure showing historian data.

![Connected Factory Item Publish Link Insights](pictures/connected-factory-opc_server_publish_insigths_link.PNG)

The published data can be viewed.

![Time Series Insights](pictures/TimeSeriesInsights_Publishdata.PNG)  

Alternatively in the *Data* tab of the Device Explorer the iot-edge-opc-publisher can also be monitored for new values.

![Device Explorer Data View](pictures/Device-Explorer-Publishdata.PNG)  

To stop publishing new values to the Azure IoT hub, right click the item to bring up the *unpublish* option  

![Connected Factory Item Context Menu](pictures/connected-factory-opc_server_context_menu_unpublish.PNG)  

After unpublishing no further data for this item will be send to the Azure IoT hub. The violett hook disappears.

![Connected Factory Item Unpublish](pictures/connected-factory-opc_server_unpublish.PNG)  

---

Continue reading with:  
    * [Table of Content](README.md#table-of-content)  
    * [Troubleshooting](troubleshooting.md#troubleshooting)  

